using System.Diagnostics;
using Microsoft.VisualBasic;
using System;
using System.Data;
using System.Collections;
using AxWMPLib;
using WMPLib;

namespace WindowsMediaPlayerAddIn
{
	
	public static class WindowsMediaController
	{
		private static AxWindowsMediaPlayer _player;
		
	
		public static bool SetPlayer(ref AxWindowsMediaPlayer MediaPlayerInstance)
		{
			try
			{
				_player = MediaPlayerInstance;
			}
			catch (Exception)
			{
				return false;
			}
			return true;
		}
		public static AxWindowsMediaPlayer GetPlayer()
		{
    		return _player;
		}
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Index Of Media To Play
		//'' </summary>
		//'' <remarks>
		//'' This is the Index that is set so that when the Player knows which item in
		//'' its playlist to play
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		private static int _intIndexOfMediaToPlay;
		public static int IndexOfMediaToPlay
		{
			get{
				return _intIndexOfMediaToPlay;
			}
			set
			{
				_intIndexOfMediaToPlay = value;
			}
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Index Of Playing Media
		//'' </summary>
		//'' <value></value>
		//'' <remarks>
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/4/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		private static int _intIndexOfPlayingMedia = -1;
		public static int IndexOfPlayingMedia
		{
            get
            {
                string theFileName = _player.currentMedia.sourceURL;
                if (_player.currentPlaylist.count > 0)
                {
                    for (int i = 0; i < _player.currentPlaylist.count; i++)
                    {
                        if (theFileName.Equals(_player.currentPlaylist.get_Item(i).sourceURL))
                        {
                            _intIndexOfPlayingMedia = i;
                            break;
                        }
                    }
                }
                else
                {
                    _intIndexOfPlayingMedia = -1;
                }
                return _intIndexOfPlayingMedia;
            }
         
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Play
		//'' </summary>
		//'' <remarks>
		//'' Play Command. Starts Playing
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerPlay ()
		{
			if (_player.currentPlaylist.count > 0)
			{
				_player.Ctlcontrols.playItem(_player.currentPlaylist.get_Item(_intIndexOfMediaToPlay));
			}
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Stop
		//'' </summary>
		//'' <remarks>
		//'' Command To Stop Playback
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerStop ()
		{
			_player.Ctlcontrols.stop();
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Pause
		//'' </summary>
		//'' <remarks>
		//'' Command to Pause / Unpause Player
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerPause ()
		{
			if (_player.playState == WMPLib.WMPPlayState.wmppsPlaying)
			{
				_player.Ctlcontrols.pause();
			}
			else if (_player.playState == WMPLib.WMPPlayState.wmppsPaused)
			{
				_player.Ctlcontrols.play();
			}
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Fast Forward
		//'' </summary>
		//'' <param name="Increment"></param>
		//'' <remarks>
		//'' Fast Forwards Media By Value Indicated By Increment
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerFF (double Increment)
		{
			_player.Ctlcontrols.currentPosition += Increment;
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Rewind
		//'' </summary>
		//'' <param name="Increment"></param>
		//'' <remarks>
		//'' Rewinds Media By Value Indicated In Increment
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerRW (double Increment)
		{
			_player.Ctlcontrols.currentPosition -= Increment;
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Remove Item
		//'' </summary>
		//'' <param name="Index"></param>
		//'' <remarks>
		//'' Overloaded Media Player Playlist Item Is Removed At Position Indicated
		//'' By Index, Media List Item is also removed at the same Index, Otherwise
		//'' we use the Index of _intIndexOfMediaToPlay, which should be set as a
		//'' reference to the next media that will be selected / Played
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerRemoveItem (int Index)
		{
			_player.currentPlaylist.removeItem(_player.currentPlaylist.get_Item(Index));
		}
		public static void MediaPlayerRemoveItem ()
		{
			//Dim l As MediaLogic.MediaList = MediaListHandle.GetInstance
			_player.currentPlaylist.removeItem(_player.currentPlaylist.get_Item(_intIndexOfMediaToPlay));
			//l.RemoveAt(_intIndexOfMediaToPlay)
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Playlist Clear
		//'' </summary>
		//'' <remarks>
		//'' Clears All Items From Current Playlist
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerPlaylistClear ()
		{
			_player.currentPlaylist.clear();
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Playlist Append
		//'' </summary>
		//'' <param name="Path"></param>
		//'' <remarks>
		//'' Appends New Item To Current Media Player Playlist
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerPlaylistAppend (string Path)
		{
			_player.currentPlaylist.appendItem(_player.newMedia(Path));
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Duration String
		//'' </summary>
		//'' <param name="Index"></param>
		//'' <returns></returns>
		//'' <remarks>
		//'' 00:00:00 Gets The Media Duration String. Overloaded. Returns Information For
		//'' The Current Media Item or the Media Item At The Index Specified By Index
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static string MediaPlayerMediaDurationString(int Index)
		{
            return _player.currentPlaylist.get_Item(Index).durationString;
		}
		public static string MediaPlayerMediaDurationString()
		{
			return _player.currentMedia.durationString;
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Duration
		//'' </summary>
		//'' <param name="Index"></param>
		//'' <returns></returns>
		//'' <remarks>
		//'' 2345.4334333 Gets The Media Duration . Overloaded. Returns Information For
		//'' The Current Media Item or the Media Item At The Index Specified By Index
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static double MediaPlayerMediaDuration(int Index)
		{
            return _player.currentPlaylist.get_Item(Index).duration;
		}
		public static double MediaPlayerMediaDuration()
		{
			return _player.currentMedia.duration;
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Media Position String
		//'' </summary>
		//'' <returns></returns>
		//'' <remarks>
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static string MediaPlayerMediaPositionString()
		{
			return _player.Ctlcontrols.currentPositionString;
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Media Position
		//'' </summary>
		//'' <returns></returns>
		//'' <remarks>
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static double MediaPlayerMediaPosition()
		{
			return _player.Ctlcontrols.currentPosition;
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Set Media Position
		//'' </summary>
		//'' <param name="Position"></param>
		//'' <remarks>
		//'' Sets The Current Media Position To Location Indicated By Position
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerSetMediaPosition (double Position)
		{
			if (_player.currentMedia == null)
			{
				return;
			}
			if (Position <= _player.currentMedia.duration)
			{
				_player.Ctlcontrols.currentPosition = Position;
			}
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Media Type
		//'' </summary>
		//'' <returns></returns>
		//'' <remarks>
		//'' Returns The File / Media Type Of Playlist Item. Overloaded, Returns Info of
		//'' Current Media Item or Playlist Item Indicated By Index
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static string MediaPlayerMediaType()
		{
			return _player.currentMedia.getItemInfo("MediaType");
		}
		public static string MediaPlayerMediaType(int Index)
		{
			return _player.currentPlaylist.get_Item(Index).getItemInfo("MediaType");
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player CD Eject
		//'' </summary>
		//'' <param name="Index"></param>
		//'' <remarks>
		//'' Ejects CD Rom. Overloaded, Ejects CD Rom Specified At Index of CD Rom
		//'' Collection Or By Drive Letter
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerCdEject (int Index)
		{
			_player.cdromCollection.Item(Index).eject();
		}
		public static void MediaPlayerCdEject (string DriveLetter)
		{
			_player.cdromCollection.getByDriveSpecifier(DriveLetter).eject();
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player CD Play
		//'' </summary>
		//'' <param name="DriveIndex"></param>
		//'' <param name="MediaIndex"></param>
		//'' <remarks>
		//'' Plays CD Item At Specified CD Drive. Overloaded, Plays Item At CD Drive In
		//'' CDRom Collection by Index Or By Drive Letter.
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static void MediaPlayerCdPlay (int DriveIndex, int MediaIndex)
		{
            _player.Ctlcontrols.playItem(_player.cdromCollection.Item(DriveIndex).Playlist.get_Item(MediaIndex));
		}
		public static void MediaPlayerCdPlay (string DriveLetter, int MediaIndex)
		{
            _player.Ctlcontrols.playItem(_player.cdromCollection.getByDriveSpecifier(DriveLetter).Playlist.get_Item(MediaIndex));
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Get CD Drives
		//'' </summary>
		//'' <returns></returns>
		//'' <remarks>
		//'' Returns String Array Of All CD Roms On Computer
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static string[] MediaPlayerCdGetDrives()
		{
			ArrayList s = new ArrayList();
			
			for (int i = 0; i <= _player.cdromCollection.count - 1; i++)
			{
				s.Add(_player.cdromCollection.Item(i).driveSpecifier.Replace(":", ""));
			}
			
			return ((string[])(s.ToArray(typeof(string))));
		}
		
		public static int MediaPlayerVolume
		{
			get{
				return _player.settings.volume;
			}
			set
			{
				_player.settings.volume = value;
			}
		}
		
		public static int MediaPlayerBalance
		{
			get{
				return _player.settings.balance;
			}
			set
			{
				_player.settings.balance = value;
			}
		}
		
		public static bool MediaPlayerMute
		{
			get{
				return _player.settings.mute;
			}
			set
			{
				_player.settings.mute = value;
			}
		}
		
		public static bool MediaPlayerLoopAll
		{
			get{
				return _player.settings.getMode("loop");
			}
			set
			{
				_player.settings.setMode("loop", value);
			}
		}
		
		public static bool MediaPlayerRandom
		{
			get{
				return _player.settings.getMode("shuffle");
			}
			set
			{
				_player.settings.setMode("shuffle", value);
			}
		}
		
		public static void MediaPlayerNextMedia ()
		{
			_player.Ctlcontrols.next();
		}
		
		public static void MediaPlayerPreviousMedia ()
		{
			_player.Ctlcontrols.previous();
		}
		
		//'' -----------------------------------------------------------------------------
		//'' <summary>
		//'' Media Player Get Current State
		//'' </summary>
		//'' <returns></returns>
		//'' <remarks>
		//'' Returns String Value Of Current Media Player PlayState
		//'' </remarks>
		//'' <history>
		//'' 	[Tom P]	7/3/2004	Created
		//'' </history>
		//'' -----------------------------------------------------------------------------
		public static string MediaPlayerGetCurrentState()
		{
			switch (_player.playState)
			{
				case WMPLib.WMPPlayState.wmppsPlaying:
					
					return "Playing";
				case WMPLib.WMPPlayState.wmppsPaused:
					
					return "Paused";
				case WMPLib.WMPPlayState.wmppsStopped:
					
					return "Stopped";
				case WMPLib.WMPPlayState.wmppsReady:
					
					return "Ready";
				case WMPLib.WMPPlayState.wmppsBuffering:
					
					return "Buffering";
				case WMPLib.WMPPlayState.wmppsWaiting:
					
					return "Waiting";
				default:
					
					return "";
			}
		}
	}
}
