using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

using AxWMPLib;
using MediaPlayerCommon;

using Microsoft.Practices.CompositeUI.EventBroker;
using Microsoft.Practices.CompositeUI.Commands;
using Microsoft.Practices.CompositeUI.SmartParts;

namespace WindowsMediaPlayerAddIn
{
    [SmartPart]
    public partial class WindowsMediaPlayerView : UserControl, ISmartPartInfoProvider
    {
        public WindowsMediaPlayerView()
        {
            InitializeComponent();
            WindowsMediaController.SetPlayer(ref this.theWindowsMediaPlayer);
        }

        #region Event Publications

        [EventPublication("event://CurrentMediaItemChanged", PublicationScope.Global)]
        public event EventHandler<MediaEventArgs> CurrentMediaItemChanged;

        protected void onCurrentMediaItemChanged(MediaEventArgs e)
        {
            if (CurrentMediaItemChanged != null)
            {
                CurrentMediaItemChanged(this, e);
            }
        }


        #endregion
        
        [EventSubscription("event://MediaCollectionInitialized")]
        public void MediaCollectionInitialized(object Sender, MediaCollectionEventArgs e)
        {
            WindowsMediaController.MediaPlayerPlaylistClear();

            foreach (MediaFile f in e.MediaCollection)
            {
                WindowsMediaController.MediaPlayerPlaylistAppend(f.FileInfo.FullName);
            }

        }

        [EventSubscription("event://PlayCommandRequested")]
        public void PlayCommandRequested(object Sender, MediaEventArgs e)
        {
            WindowsMediaController.IndexOfMediaToPlay = e.MediaIndex;
            WindowsMediaController.MediaPlayerPlay();
        }

        [CommandHandler("Play")]
        public void onPlayCommand(object Sender, EventArgs e)
        {
            WindowsMediaController.MediaPlayerPlay();
        }

        [CommandHandler("Stop")]
        public void onStopCommand(object Sender, EventArgs e)
        {
            WindowsMediaController.MediaPlayerStop();
        }

        [CommandHandler("Pause")]
        public void onPauseCommand(object Sender, EventArgs e)
        {
            WindowsMediaController.MediaPlayerPause();
        }

        private void theWindowsMediaPlayer_CurrentItemChange(object sender, _WMPOCXEvents_CurrentItemChangeEvent e)
        {
            this.onCurrentMediaItemChanged(
                new MediaEventArgs(WindowsMediaController.IndexOfPlayingMedia, new MediaFile(WindowsMediaController.GetPlayer().currentMedia.sourceURL)));
        }

        public Microsoft.Practices.CompositeUI.SmartParts.ISmartPartInfo GetSmartPartInfo(Type smartPartInfoType)
        {
            // Implement ISmartPartInfoProvider in the containing smart part. Required in order for contained smart part infos to work.
            Microsoft.Practices.CompositeUI.SmartParts.ISmartPartInfoProvider ensureProvider = this;
            return this.infoProvider.GetSmartPartInfo(smartPartInfoType);

        }
    }
}
